@@ -1,10 +1,7 @@
 # /bin/sh
 mkdir ./bin/translations
-cd src
-lrelease src.pro
-qmake src.pro
-cd ..
-cp ./src/translations/*.qm ./bin/translations
+lrelease ifpgui.pro
+cp ./translations/*.qm ./bin/translations
 qmake ifpgui.pro
 make
 echo " "
@@ -13,8 +10,8 @@ echo " "
 #echo "You will need root privilage for this."
 #su -c ./nonroot.sh
 echo "if you have trouble connecting to your iRiver device,"
-echo "run the script ./nonroot.sh."
+echo "run the script ./bin/nonroot.sh."
 echo " "
 echo " "
-echo "to run: change directory to 'bin' and type './ifpgui'"
+echo "to run ifpgui: change directory to 'bin' and type './ifpgui'"
 
